part of sonarr_commands;

/// Facilitates, encapsulates, and manages individual calls related to series within Sonarr.
/// 
/// [SonarrCommandHandler_Series] internally handles routing the HTTP client to the API calls.
class SonarrCommandHandler_Series {
    final Dio _client;

    /// Create a series command handler using an initialized [Dio] client.
    SonarrCommandHandler_Series(this._client);

    /// Handler for [series/{id}](https://github.com/Sonarr/Sonarr/wiki/Series#getid).
    /// 
    /// Returns the series with the matching ID.
    /// 
    /// Required Parameters:
    /// - `seriesId`: Series ID for the series to return
    Future<SonarrSeries> getSeries({
        @required int seriesId,
    }) async => _commandGetSeries(_client, seriesId: seriesId);

    /// Handler for [series](https://github.com/Sonarr/Sonarr/wiki/Series#get).
    /// 
    /// Returns a list of all series.
    Future<List<SonarrSeries>> getAllSeries() async => _commandGetAllSeries(_client);
}
